@@ -7,7 +7,7 @@ vardannual <- function(Y, H, PSU, w_final, ID_level1,
                        countryX = NULL, yearsX = NULL,
                        subperiodsX = NULL, X_ID_level1 = NULL,
                        ind_gr = NULL, g = NULL, q = NULL,
-                       datasetX = NULL, percentratio = 1,
+                       datasetX = NULL, frate = 0, percentratio = 1,
                        use.estVar = FALSE, use.gender = FALSE,
                        confidence = 0.95, method = "cros") {
 
@@ -18,6 +18,7 @@ vardannual <- function(Y, H, PSU, w_final, ID_level1,
   use.estVar <- check_var(vars = use.estVar, varn = "use.estVar", varntype = "logical")
   use.gender <- check_var(vars = use.gender, varn = "use.gender", varntype = "logical")
   confidence <- check_var(vars = confidence, varn = "confidence", varntype = "numeric01")
+  frate <- check_var(vars = frate, varn = "frate", varntype = "numeric0100")
 
   if(!is.null(X)) {
          if (is.null(datasetX)) datasetX <- copy(dataset)
@@ -78,11 +79,13 @@ vardannual <- function(Y, H, PSU, w_final, ID_level1,
 
   subperiods <- check_var(vars = subperiods, varn = "subperiods",
                           dataset = dataset, ncols = 1, Ynrow = Ynrow,
-                          ischaracter = TRUE, dif_name = c("percoun", "period_country", names(country), "yearg", "Nrs"))
+                          ischaracter = TRUE, years = years,
+                          dif_name = c("percoun", "period_country", names(country), "yearg", "Nrs"))
   subpm <- names(subperiods)
   subn <- data.table(years, subperiods)
-  subn <- nrow(subn[, .N, by = names(subn)]) / length(unique(subn[["yearg"]]))
-  
+  subn <- subn[, .N, by = c(names(subn))]
+  subn <- max(subn[, .N, by = names(years)][["N"]])
+ 
   ID_level1 <- check_var(vars = ID_level1, varn = "ID_level1",
                          dataset = dataset, ncols = 1, Ynrow = Ynrow,
                          ischaracter = TRUE)
@@ -153,9 +156,12 @@ vardannual <- function(Y, H, PSU, w_final, ID_level1,
          }
    dataset <- datasetX <- NULL
 
+
+
    ids <- nams <- cros_se <- num1 <- totalY <- totalZ <- NULL
    estim_1 <- estim_2 <- avar <- N <- estim <- NULL
    var_est2 <- se <- rse <- cv <- CI_lower <- CI_upper <- NULL
+   absolute_margin_of_error <- relative_margin_of_error <- NULL
    Nr_sar <- cols <- Nrs <- percoun <- totalY_male <- NULL
    totalZ_male <- totalY_female <- totalZ_female <- NULL  
 
@@ -295,7 +301,7 @@ vardannual <- function(Y, H, PSU, w_final, ID_level1,
                   X <- cros_rho[["cros_se"]]
 
                   annual_var <- data.table(rho2[1, sar, with = FALSE],
-                                             1 / (subn)^2 * (t(X) %*% A_matrix) %*% X)
+                                             (1 - frate / 100) / (subn)^2 * (t(X) %*% A_matrix) %*% X)
                   setnames(annual_var, c("V1"), c("var"))
                   A_matrix <- data.table(rho2[1, sar, with = FALSE], cols = paste0("V", 1 : nrow(A_matrix)), A_matrix)
                   list(cros_rho, A_matrix, annual_var)})
@@ -382,13 +388,17 @@ vardannual <- function(Y, H, PSU, w_final, ID_level1,
                             annual_results[, cv := rse * 100] }
 
    tsad <- qnorm(0.5 * (1 + confidence))
+   if (method == "cros") {
+          annual_results[, absolute_margin_of_error := tsad * se]
+          annual_results[, relative_margin_of_error := tsad * cv]
+   }
    annual_results[, CI_lower := estim - tsad * se]
    annual_results[, CI_upper := estim + tsad * se]
 
    if (method != "cros") {
               significant <- NULL
-              annual_results[, significant := TRUE]
-              annual_results[CI_lower <= 0 & CI_upper >= 0, significant := FALSE]
+              annual_results[, significant := "YES"]
+              annual_results[CI_lower <= 0 & CI_upper >= 0, significant := "NO"]
    }
 
    list(crossectional_results = crossectional_results,
